@@ -3,41 +3,16 @@
 Defines the basic terms and functions for nonogram game
 """
 
-from __future__ import print_function, unicode_literals
 
+from notetool.tool.log import logger
 from six import integer_types, iteritems, string_types, with_metaclass
 from six.moves import range
 
-from ..utils.iter import expand_generator, list_replace
-from ..utils.other import get_named_logger
-from .color import Color, ColorBlock
-
-try:
-    from enum import Enum
-except ImportError:
-    Enum = object
-
-
-LOG = get_named_logger(__name__, __file__)
-
-
-class NonogramError(ValueError):
-    """
-    Represents an error occurred when trying
-    to solve a nonogram which has an internal contradiction.
-    """
-
-
-UNKNOWN = None  # this cell has to be solved
-
-
-class BlackAndWhite(Enum):
-    """
-    Enums are faster than simple integers
-    """
-    WHITE = Color.white().id_
-    BLACK = Color.black().id_
+from notegame.games.nonogram.core.color import Color, ColorBlock
+from notegame.games.nonogram.utils.iter import expand_generator, list_replace
 
+# this cell has to be solved
+UNKNOWN = None
 
 # but boolean constants are even faster than Enums
 BOX = True  # BlackAndWhite.BLACK
@@ -46,6 +21,15 @@ SPACE = False  # BlackAndWhite.WHITE
 # for colored puzzles only integer is allowed
 SPACE_COLORED = Color.white().id_
 
+BLACK_AND_WHITE_COLORS = (UNKNOWN, SPACE, BOX)
+
+
+class NonogramError(ValueError):
+    """
+    Represents an error occurred when trying
+    to solve a nonogram which has an internal contradiction.
+    """
+
 
 def invert(cell_state):
     """
@@ -110,14 +94,14 @@ def normalize_row(row):
     if is_color_list(row):
         return row
 
-    LOG.debug('All row symbols: %s', alphabet)
+    logger.debug('All row symbols: %s', alphabet)
     # save original for logs and debug
     original, row = row, list(row)
 
     for formal, informal in iteritems(INFORMAL_REPRESENTATIONS):
         informal = set(informal) & alphabet
         if not informal:
-            LOG.debug('Not found %r in a row', formal)
+            logger.debug('Not found %r in a row', formal)
             continue
 
         if len(informal) > 1:
@@ -127,7 +111,7 @@ def normalize_row(row):
                     ', '.join(sorted(informal)), formal, original))
 
         informal = informal.pop()
-        LOG.debug('Replace %r with a %r', informal, formal)
+        logger.debug('Replace %r with a %r', informal, formal)
         list_replace(row, informal, formal)
 
     assert set(row).issubset(FORMAL_ALPHABET)
@@ -139,9 +123,6 @@ def is_list_like(value):
     return isinstance(value, (tuple, list))
 
 
-BLACK_AND_WHITE_COLORS = (UNKNOWN, SPACE, BOX)
-
-
 def is_color_cell(value):
     """
     Whether the value is a combination of several colors
